==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-resource-management/src/main/java/org/apache/streampipes/resource/management/DataStreamResourceManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.resource.management;

import org.apache.streampipes.model.SpDataSet;
import org.apache.streampipes.model.SpDataStream;
import org.apache.streampipes.storage.api.IDataStreamStorage;
import org.apache.streampipes.storage.management.StorageDispatcher;

public class DataStreamResourceManager
    extends AbstractPipelineElementResourceManager<IDataStreamStorage, SpDataStream, SpDataStream> {

  public DataStreamResourceManager(IDataStreamStorage db) {
    super(db);
  }

  public DataStreamResourceManager() {
    super(StorageDispatcher.INSTANCE.getNoSqlStore().getDataStreamStorage());
  }

  @Override
  protected SpDataStream toInvocation(SpDataStream description) {
    return description instanceof SpDataSet ? new SpDataSet((SpDataSet) description) : new SpDataStream(description);
  }

  /**
   * Takes a data stream {@link SpDataStream} as an input updates it in the database
   */
  public void update(SpDataStream dataStream) {
    db.updateElement(dataStream);
  }
}

==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-resource-management/src/main/java/org/apache/streampipes/resource/management/DataStreamResourceManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.resource.management;

import org.apache.streampipes.model.SpDataStream;
import org.apache.streampipes.storage.api.IDataStreamStorage;
import org.apache.streampipes.storage.management.StorageDispatcher;

public class DataStreamResourceManager
    extends AbstractPipelineElementResourceManager<IDataStreamStorage, SpDataStream, SpDataStream> {

  public DataStreamResourceManager(IDataStreamStorage db) {
    super(db);
  }

  public DataStreamResourceManager() {
    super(StorageDispatcher.INSTANCE.getNoSqlStore().getDataStreamStorage());
  }

  @Override
  protected SpDataStream toInvocation(SpDataStream description) {
    return new SpDataStream(description);
  }

  /**
   * Takes a data stream {@link SpDataStream} as an input updates it in the database
   */
  public void update(SpDataStream dataStream) {
    db.updateElement(dataStream);
  }
}
